@@ -6,7 +6,7 @@ use base 'Mail::Message::Body';
 
 use Mail::Box::Parser;
 
-our $VERSION = 2.005;
+our $VERSION = 2.006;
 
 use Carp;
 use IO::File;
@@ -192,7 +192,7 @@ sub print(;$)
 
 #------------------------------------------
 
-sub _data_from_filename(@_)
+sub _data_from_filename(@)
 {   my ($self, $filename) = @_;
 
     unless(open IN, '<', $filename)
@@ -216,7 +216,7 @@ sub _data_from_filename(@_)
     $self;
 }
 
-sub _data_from_filehandle(@_)
+sub _data_from_filehandle(@)
 {   my ($self, $fh) = @_;
     my $file    = $self->tempFilename;
     my $nrlines = 0;
@@ -237,7 +237,7 @@ sub _data_from_filehandle(@_)
     $self;
 }
 
-sub _data_from_glob(@_)
+sub _data_from_glob(@)
 {   my ($self, $fh) = @_;
     my $file    = $self->tempFilename;
     my $nrlines = 0;
@@ -257,7 +257,7 @@ sub _data_from_glob(@_)
     $self;
 }
 
-sub _data_from_lines(@_)
+sub _data_from_lines(@)
 {   my ($self, $lines)  = @_;
     my $file = $self->tempFilename;
 
@@ -347,7 +347,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is beta, version 2.005.
+This code is beta, version 2.006.
 
 Copyright (c) 2001 Mark Overmeer. All rights reserved.
 This program is free software; you can redistribute it and/or modify
